@@ -1,6 +1,6 @@
 from django.db import models
 
-from model_utils.models import InheritanceCastModel
+from model_utils.models import InheritanceCastModel, TimeStampedModel
 
 class InheritParent(InheritanceCastModel):
     pass
@@ -8,3 +8,5 @@ class InheritParent(InheritanceCastModel):
 class InheritChild(InheritParent):
     pass
 
+class TimeStamp(TimeStampedModel):
+    pass
