@@ -1,7 +1,7 @@
 from django.test import TestCase
 from django.contrib.contenttypes.models import ContentType
 
-from model_utils.tests.models import InheritParent, InheritChild
+from model_utils.tests.models import InheritParent, InheritChild, TimeStamp
 
 class InheritanceCastModelTests(TestCase):
     def setUp(self):
@@ -19,3 +19,16 @@ class InheritanceCastModelTests(TestCase):
     def testCast(self):
         obj = InheritParent.objects.get(pk=self.child.pk).cast()
         self.assertEquals(obj.__class__, InheritChild)
+
+
+class TimeStampedModelTests(TestCase):
+    def testCreated(self):
+        t1 = TimeStamp.objects.create()
+        t2 = TimeStamp.objects.create()
+        self.assert_(t2.created > t1.created)
+
+    def testModified(self):
+        t1 = TimeStamp.objects.create()
+        t2 = TimeStamp.objects.create()
+        t1.save()
+        self.assert_(t2.modified < t1.modified)
